@@ -48,8 +48,9 @@ sub create_ikc_channel
                     error  => \&channel_error,
 
                     receive => \&channel_receive,
-                    'send' => \&channel_send,
-                    'done' => \&channel_done,
+                    'send'  => \&channel_send,
+                    'done'  => \&channel_done,
+                    'close' => \&channel_close,
                     server_000 => \&server_000,
                     server_001 => \&negociate_001,
                     server_002 => \&server_002,
@@ -138,8 +139,7 @@ sub _negociation_done
         $kernel->yield('done');
     }
 
-    return
-
+    return;
 }
 
 #----------------------------------------------------
@@ -415,7 +415,7 @@ sub channel_error
 #
 sub channel_default
 {
-    my($event)=$_[ARG0];
+    my($event)=$_[STATE];
     DEBUG && print "Unknown event $event posted to IKC::Channel\n"
         if $event !~ /^_/;
     return;
@@ -423,10 +423,10 @@ sub channel_default
 
 #----------------------------------------------------
 # Process POE's standard _stop event by shutting down.
-
 sub channel_shutdown 
 {
-    my $heap = $_[ARG0];
+    my $heap = $_[HEAP];
+#    warn "$heap channel_shutdown\n";
     DEBUG && print "Channel has shut down.\n";
     delete $heap->{wheel_client};
 }
@@ -454,6 +454,7 @@ sub channel_receive
     # call the Responder channel to process
     # hmmm.... i wonder if this could be stream-lined into a direct call
     $kernel->call('IKC', 'request', $request);
+    return;
 }
 
 #----------------------------------------------------
@@ -470,6 +471,15 @@ sub channel_send
     return $heap->{'wheel_client'}->put($request);
 }
 
+#----------------------------------------------------
+# Local kernel things it's time to close down the channel
+sub channel_close
+{
+    my ($heap)=$_[HEAP];
+#    warn "$heap channel_close\n";
+    delete $heap->{'wheel_client'};
+}
+
 ###########################################################################
 
 
