@@ -41,7 +41,7 @@ sub create_ikc_client
     $parms{port}||=603;                 # POE! (almost :)
     $parms{name}||="Client$$";
     $parms{subscribe}||=[];
-    new POE::Session( __PACKAGE__, [qw(_start error connected)], [\%parms]);
+    new POE::Session( __PACKAGE__, [qw(_start _stop error connected)], [\%parms]);
 }
 
 
@@ -94,6 +94,11 @@ sub connected
     
 }
 
+sub _stop
+{
+#    warn "$_[HEAP] client _stop\n";
+}
+
 1;
 __END__
 # Below is the stub of documentation for your module. You better edit it!
