@@ -139,6 +139,11 @@ sub connect
     return 1;
 }
 
+#----------------------------------------------------
+sub error
+{
+    return $error;
+}
 #----------------------------------------------------
 sub ping
 {
@@ -166,6 +171,11 @@ sub disconnect
     delete @{$self->{remote}}{qw(socket connected name aliases)};
 }
 
+sub DISTROY 
+{
+    my($self)=@_;
+    $self->disconnect;
+}
 sub END
 {
     # print 'end';
@@ -215,6 +225,32 @@ sub call
     return $ret;
 }
 
+#----------------------------------------------------
+# posts an event, waits for the response, returns the response
+# this differs from call() in that the foreign server may
+# need many states before getting a response
+sub post_respond
+{
+    my($self, $spec, $params)=@_;
+    $spec="poe://$self->{remote}{name}/$spec" unless ref $spec or $spec=~m(^poe:);
+
+    my $ret;
+    my $rsvp={kernel=>$self->{name}, session=>'IKCLite',
+              state=>'response'.$request++};
+    $ret=eval { 
+        return unless $self->_try_send({event=>$spec, 
+                                        params=>[$params, $rsvp], 
+                                       }); 
+        DEBUG && print "Waiting for response...\n";
+        return $self->_response($rsvp);
+    };
+    if($@) {
+        $error=$@;
+        return;
+    }
+    return $ret;
+}
+
 #----------------------------------------------------
 sub _try_send
 {
@@ -296,6 +332,7 @@ sub _response
             die "Hey!  $s isn't $remote->{socket}" 
                 unless $s eq $remote->{socket};
         }
+        DEBUG && print "Got something...\n";
         
                                     # read in another chunk
         $l=$remote->{socket}->sysread($raw, 512, length($raw)); 
@@ -305,22 +342,31 @@ sub _response
             die "Error reading: $!\n";
         }
 
-        $need=$1 if not $need and $raw=~s/(\d+)\0//s;   # look for a marker?
+        if(not $need and $raw=~s/(\d+)\0//s) {  # look for a marker?
+            $need=$1 ;
+            DEBUG && print "Need $need bytes...\n";
+        }
+
         next unless $need;                      # still looking...
 
         if(length($raw) >= $need)               # do we have all we want?
         {
+            DEBUG && print "Got it all...\n";
+
             $frozen=substr($raw, 0, $need);     # seems so...
             substr($raw, 0, $need)='';
-            my $msg=$self->{remote}{thaw}->($frozen);   # freeze the message
+            my $msg=$self->{remote}{thaw}->($frozen);   # thaw the message
             my $to=specifier_parse($msg->{event});
+            DEBUG && print Dumper $msg;
 
             die $msg->{params} if($msg->{is_error});    # throw an error out
+            DEBUG && print "Not an error...\n";
 
                 # make sure it's what we're waiting for...
             if($to->{session} ne 'IKC' and $to->{session} ne 'IKCLite')
             {
                 warn "Unknown session $to->{session}\n";
+                DEBUG && print "Not for us!  ($to->{session})...\n";
                 next;
             }
             if($to->{session} ne $rsvp->{session} or
@@ -328,6 +374,7 @@ sub _response
             {
                 warn specifier_name($to). " received, expecting " .
                      specifier_name($rsvp). "\n";
+                DEBUG && print "Not for us!  ($to->{session}/$to->{state})...\n";
                 next;
             }
             return $msg->{params};              # finaly!
