@@ -12,8 +12,6 @@ package POE::Component::IKC::Specifier;
 
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-use Carp;
-use POE;
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -33,7 +31,7 @@ sub specifier_parse ($)
         if($specifier=~m(^poe:
                         (?:
                             (//)
-                            (\*|[- \w]+|[a-zA-Z0-9][-.a-zA-Z0-9]+:\d+)?
+                            (\*|[-. \w]+|[a-zA-Z0-9][-.a-zA-Z0-9]+:\d+)?
                         )?
                         (?:
                             (/)
@@ -90,6 +88,7 @@ sub specifier_name ($)
 1;
 
 __END__
+
 =head1 NAME
 
 POE::Component::IKC::Speicier - POE Inter-Kernel Communication specifer
